.. _{{ fullname }}:


.. raw:: html

    <br>

.. title:: {{ fullname }}


.. raw:: html

    <center>
    <b>

:ref:`SRC <source>`/**{{ name }}**

.. raw:: html

    </b>
    </center>


**{{ fullname }}**


.. auto{{ objtype }}:: {{ fullname }}
    :members:
    :private-members:
    :undoc-members:
